@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import six
 from cacheops.conf import redis_client, handle_connection_failure
 from cacheops.utils import get_model_name, non_proxy
 
@@ -30,12 +31,12 @@ class ConjSchemes(object):
         self.versions = {}
 
     def get_lookup_key(self, model_or_name):
-        if not isinstance(model_or_name, basestring):
+        if not isinstance(model_or_name, six.string_types):
             model_or_name = get_model_name(model_or_name)
         return 'schemes:%s' % model_or_name
 
     def get_version_key(self, model_or_name):
-        if not isinstance(model_or_name, basestring):
+        if not isinstance(model_or_name, six.string_types):
             model_or_name = get_model_name(model_or_name)
         return 'schemes:%s:version' % model_or_name
 
